#ifdef RCSID
static char RCSid[] =
"$Header: d:/cvsroot/tads/TADS2/mac/OS0TR_MA.C,v 1.2 1999/05/17 02:52:18 MJRoberts Exp $";
#endif

/* Copyright (c) 1992 by Michael J. Roberts.  All Rights Reserved. */
/*
Name
  os0tr.c - os mainline for tads2 run-time for Macintosh
Function
  invokes runtime from operating system command line
Notes
  none
Modified
  04/04/92 MJRoberts     - creation
*/

#include <assert.h>

#include <Types.h>
#include <ToolUtils.h>
#include <Scrap.h>
#include <StandardFile.h>
#include <Dialogs.h>
#include <Files.h>
#include <Windows.h>
#include <Lists.h>
#include <Menus.h>
#include <Events.h>
#include <Sound.h>
#include <AppleEvents.h>
#include <TextUtils.h>

#include "std.h"
#include "os.h"
#include "ossmac.h"
#include "cmd.h"
#include "configs.h"
#include "trd.h"

extern WindowPtr myWindow;

/* declaration of DoCommand in ossmac.c -- it really ought to be here instead. */
int DoCommand(long mResult);
void runtimeMenuSetup(void);

static int getgamefile(Str255 gamefile);

static void setbutton(DialogPtr mydlg, short button, short checkbox)
{
        /* enable or disable button according to check box */
        HiliteControlItem(mydlg, button, GetControlItemValue(mydlg, checkbox) ? 0 : 255);
}


struct tropts_t {
        Str255          gamefile;
        Str255          savefile;
        Str255          inputcommandfile;
        Str255          outputcommandfile;
        Str255          logfile;
//      Boolean         plain;
        Boolean         doublespace;
        Boolean         swappingallowed;
        Str255          swapfile;
        uint            stacksize;
        uint            heapsize;
        ushort          undosize;
        ulong           cachelimit;
        char            safetylevel;
        
        void setdefault();
        tropts_t() { this->setdefault(); }
};

void tropts_t::setdefault()
{
        memset(this, 0, sizeof(tropts_t));
        doublespace = true;
        stacksize = TRD_STKSIZ;
        heapsize = TRD_HEAPSIZ;
        undosize = TRD_UNDOSIZ;
        StringCopy_pp(swapfile, "\p<Default>", sizeof(swapfile));
        safetylevel = '0';
}

static void readcommandline(char *buf, tropts_t &opts)
{
        const int       MAX_ARGS = 64;
        
        int                     argc;
        char       *argv[MAX_ARGS], **argp;
        int                     i;
        
        argize(buf, &argc, argv, MAX_ARGS);
        
        opts.setdefault();
        
        for (i = 0, argp = argv; i < argc; i++, argp++) {
                char   *arg;
                
                arg = *argp;
                if (arg[0] == '\0') {
                        /* Someone screwed up and gave us an empty argument -- skip it. */
                }
                else if (arg[0] == '-') {
                        switch(arg[1]) {
                                case 'r': /* Restore saved game. */
                                        arg = cmdarg(NULL, &argp, &i, argc, 1, NULL);
                                        StringCopy_pc(opts.savefile, arg, sizeof(opts.savefile));
                                        break;
                                
                                case 'i': /* Command script input file. */
                                        arg = cmdarg(NULL, &argp, &i, argc, 1, NULL);
                                        StringCopy_pc(opts.inputcommandfile, arg, sizeof(opts.inputcommandfile));
                                        break;
                                
                                case 'o': /* Command script output file. */
                                        arg = cmdarg(NULL, &argp, &i, argc, 1, NULL);
                                        StringCopy_pc(opts.outputcommandfile, arg, sizeof(opts.outputcommandfile));
                                        break;
                                
                                case 'l': /* Log file. */
                                        arg = cmdarg(NULL, &argp, &i, argc, 1, NULL);
                                        StringCopy_pc(opts.logfile, arg, sizeof(opts.logfile));
                                        break;
                                
                                case 'd': /* Double space after punctuation. */
                                        if (strnicmp(arg, "-double", 7) == 0)
                                                opts.doublespace = cmdtog(NULL, opts.doublespace, arg, 6, NULL);
                                        break;
                                
                                case 's': /* File safety level. */
                                        arg = cmdarg(NULL, &argp, &i, argc, 1, NULL);
                                        if (*arg) opts.safetylevel = *arg;
                                        break;
                                
                                case 't': /* Swapping state. */
                                        if (arg[2] == '-') {
                                                opts.swappingallowed = false;
                                        }
                                        else if (arg[2] == '+') {
                                                opts.swappingallowed = true;
                                        }
                                        else if (arg[2] == 'f') {
                                                opts.swappingallowed = true;
                                                arg = cmdarg(NULL, &argp, &i, argc, 2, NULL);
                                                if (arg[0])
                                                        StringCopy_pc(opts.swapfile, arg, sizeof(opts.swapfile));
                                        }
                                        break;
                                
                                case 'm': /* Memory settings. */
                                        switch(arg[2]) {
                                                case 's': opts.stacksize  = atoi(cmdarg(NULL, &argp, &i, argc, 2, NULL)); break;
                                                case 'h': opts.heapsize   = atoi(cmdarg(NULL, &argp, &i, argc, 2, NULL)); break;
                                                default:  opts.cachelimit = atoi(cmdarg(NULL, &argp, &i, argc, 2, NULL)); break;
                                        }
                                        break;
                                
                                case 'u': /* Undo buffer size. */
                                        opts.undosize = atoi(cmdarg(NULL, &argp, &i, argc, 1, NULL));
                                        break;
                        }               
                }
                else {
                        /* If it's not argv[0] and it doesn't begin with '-', it must be the game file. */
                        if (i != 0)
                                StringCopy_pc(opts.gamefile, arg, sizeof(opts.gamefile));
                }
        }
}

static void writecommandline(const tropts_t &opts, writeoptions_t &cmdline, bool quote)
{
        #define P(s)  s[0], &s[1]
        
        #define write_nondefault(field, default, format) \
                if (opts.field != default) cmdline.write(format, opts.field);
        
        #define write_nonemptystring(field, flag) \
                if (StrLength(opts.field) > 0) cmdline.write(quote ? flag "\"%.*s\"" : flag "%.*s", P(opts.field))
        
        cmdline.write("tadsr");
        
        write_nonemptystring(savefile, "-r");
        write_nonemptystring(inputcommandfile, "-i");
        write_nonemptystring(outputcommandfile, "-o");
        write_nonemptystring(logfile, "-l");
        
        write_nondefault(doublespace, true, "-double-");
//      write_nondefault(plain, false, "-plain");
        write_nondefault(safetylevel, '0', "-s%c");
        
        if (opts.swappingallowed) {
                if (StringEqual_pc(opts.swapfile, "<Default>"))
                        // This is the default -- write nothing.
                        ; //cmdline.write("-t+");
                else
                        cmdline.write("-tf%.*s", P(opts.swapfile));
        }
        else
                cmdline.write("-t-");

        write_nondefault(stacksize, TRD_STKSIZ, "-ms%u");
        write_nondefault(heapsize, TRD_HEAPSIZ, "-mh%u");
        write_nondefault(undosize, TRD_UNDOSIZ, "-u%hu");
        write_nondefault(cachelimit, 0, "-m%lu");
        
        write_nonemptystring(gamefile, "");
        
        #undef write_nondefault
        #undef write_nonemptystring
}

static int getconfig(const char *fname, tropts_t &opts)
{
        char            buf[LINE_BUF_SIZE];
        int                     err;
        
        if ((err = readconfig(fname, "tr", "tadsr", buf, LINE_BUF_SIZE)) == noErr)
                readcommandline(buf, opts);
        
        return err;
}

static int putconfig(const char *fname, const tropts_t &opts)
{
        char    buf[LINE_BUF_SIZE];
        
        writecommandline(opts, wrtoptstring_t(buf), true);
        return writeconfig(fname, buf);
}


// =======================================================================================
// == os0getopt and helper functions.

static void GetOptionalTextItem(DialogPtr d, DialogItemIndex checkItem,
        DialogItemIndex textItem, StringPtr text)
{
        if (GetControlItemValue(d, checkItem) != 0)
                GetControlItemTitle(d, textItem, text);
        else
                text[0] = '\0';
}

// .......................................................................................

static void SetOptionalTextItem(DialogPtr d, DialogItemIndex checkItem,
        DialogItemIndex textItem, ConstStr255Param text)
{
        SetControlItemTitle(d, textItem, text);
        SetControlItemValue(d, checkItem, StrLength(text) > 0);
}

// .......................................................................................

static long GetNumberItem(DialogPtr d, DialogItemIndex item)
{
        Str255          text;
        long            n;
        
        GetControlItemTitle(d, item, text);
        StringToNum(text, &n);
        return n;
}

// .......................................................................................

static void SetNumberItem(DialogPtr d, DialogItemIndex item, long n)
{
        Str255          text;
        
        NumToString(n, text);
        SetControlItemTitle(d, item, text);
}

// .......................................................................................

static Boolean HandleFileButton(DialogPtr d, DialogItemIndex item)
{
        DialogItemIndex         item2;
        Str255                          itemText;
        const char                 *prompt;
        
        switch (item) {
                case 21:  /* select command script to read */
                        if (os0askfile("Select command script", itemText, 'TEXT', false) == 0) {
                                SetControlItemTitle(d, 13, itemText);
                                return true;
                        }
                        else
                                return false;
                        
                case 16:  /* select command script to generate */
                        item2 = 20;
                        prompt = "Save commands to:";
                        goto output_file;
                        
                case 17:  /* select output capture file */
                        item2 = 15;
                        prompt = "Save output to:";
                        goto output_file;
                        
                case 9:   /* select swap file */
                        item2 = 7;
                        prompt = "Select swap file";

                output_file:
                        if (os0askfile(prompt, itemText, 'TEXT', true) == 0) {
                                SetControlItemTitle(d, item2, itemText);
                                return true;
                        }
                        else
                                return false;
                
                default:
                        DPRINTF(("HandleFileButton: unknown item %d!", item));
                        return false;
        }                                                       
}

// ---------------------------------------------------------------------------------------

static int os0getopt(tropts_t &opts)
{
        EventRecord     myEvent;
        WindowPtr       whichWindow;
        int                     gotevent;
        short           itemHit;
        Str255          itemText;
        DialogPtr       mydlg;
        DialogPtr       dlg;
        Point           oldwhere;
        short           item2;
        short           item3;
        
        /* load dialog */
        mydlg = GetNewDialog(128, NULL, (WindowPtr) -1L);
        
        /* Set up controls based on options struct. */
        SetControlItemTitle(mydlg, 1, opts.gamefile);
        // no UI for save file.
        SetOptionalTextItem(mydlg, 19, 13, opts.inputcommandfile);
        SetOptionalTextItem(mydlg, 18, 20, opts.outputcommandfile);
        SetOptionalTextItem(mydlg, 14, 15, opts.logfile);
        // no UI for plain option.
        // no UI for doublespace option.
        // no UI for safety level.
        SetNumberItem(mydlg, 23, opts.stacksize);
        SetNumberItem(mydlg, 25, opts.heapsize);
        if (opts.cachelimit != 0)
                SetNumberItem(mydlg, 11, opts.cachelimit);
        else
                SetControlItemTitle(mydlg, 11, "\p");
        // no UI for undo size.
        SetControlItemValue(mydlg, 6, opts.swappingallowed);
        SetControlItemTitle(mydlg, 7, opts.swapfile);
        
        for (;;)
        {
                /* maintain various "select" buttons */
                setbutton(mydlg, 16, 18);
                setbutton(mydlg, 21, 19);
                setbutton(mydlg, 17, 14);
                setbutton(mydlg, 9, 6);
                setbutton(mydlg, 26, 6);
                
                /* turn on "run" button only if a game file is present */
                GetControlItemTitle(mydlg, 1, itemText);
                HiliteControlItem(mydlg, 4, itemText[0] ? 0 : 255);

                SystemTask();
                gotevent = WaitNextEvent(everyEvent, &myEvent, 0L, 0L);
                if (IsDialogEvent(&myEvent))
                {
                        oldwhere = myEvent.where;
                        
                        if (myEvent.what == updateEvt
                                && (WindowPtr)myEvent.message == (WindowPtr)mydlg)
                        {
                                /* draw box around game, swap, and script filenames */
                                SetPort((GrafPtr)mydlg);
                                drawbox(mydlg, 1);
                                drawbox(mydlg, 7);
                                drawbox(mydlg, 13);
                                drawbox(mydlg, 15);
                                drawbox(mydlg, 20);
                        }

                        if (DialogSelect(&myEvent, &dlg, &itemHit))
                        {
                                if (dlg == mydlg)
                                {
                                try_again:
                                        switch (itemHit)
                                        {
                                                case 3:   /* select game name */
                                                        if (getgamefile(itemText) == 0)
                                                                SetControlItemTitle(mydlg, 1, itemText);
                                                        break;
                                                                
                                                case 21:  /* select command script to read */
                                                case 16:  /* select command script to generate */
                                                case 17:  /* select output capture file */
                                                case 9:   /* select swap file */
                                                        HandleFileButton(mydlg, itemHit);
                                                        break;
                                                        
                                                case 26:  /* use default swap file */
                                                        SetControlItemTitle(mydlg, 7, "\p<Default>");
                                                        break;
                                                
                                                case 18:  /* check box: generate command script */
                                                        item2 = 20;
                                                        item3 = 16;
                                                        goto check_box;
                                                        
                                                case 19:  /* check box: read command script */
                                                        item2 = 13;
                                                        item3 = 21;
                                                        goto check_box;
                                                        
                                                case 14:  /* check box: capture output to file */
                                                        item2 = 15;
                                                        item3 = 17;
                                                        goto check_box;
                                                        
                                                case 6:   /* check box: allow swapping */
                                                        item2 = 7;
                                                        item3 = 9;
                                                
                                                check_box:
                                                        /* if turning on check box, and associated file name is blank,
                                                           make them pick a file.  If they cancel, turn the check box
                                                           back off. */
                                                        if (ToggleControlItemValue(mydlg, itemHit))
                                                        {
                                                                GetControlItemTitle(mydlg, item2, itemText);
                                                                if (itemText[0] == 0)
                                                                {
                                                                        if (!HandleFileButton(mydlg, item3))
                                                                                SetControlItemValue(mydlg, itemHit, 0);
                                                                }
                                                        }
                                                        break;
                                                        
                                                case 4:   /* Run button */
                                                {
                                                        // Copy all the control values into the tropts_t struct.
                                                        
                                                        GetControlItemTitle(mydlg, 1, opts.gamefile);
                                                        GetOptionalTextItem(mydlg, 19, 13, opts.inputcommandfile);
                                                        GetOptionalTextItem(mydlg, 18, 20, opts.outputcommandfile);
                                                        GetOptionalTextItem(mydlg, 14, 15, opts.logfile);
                                                        // no UI for plain option.
                                                        // no UI for doublespace option.
                                                        opts.stacksize = GetNumberItem(mydlg, 23);
                                                        opts.heapsize = GetNumberItem(mydlg, 25);
                                                        opts.cachelimit = GetNumberItem(mydlg, 11);
                                                        // no UI for undo size.
                                                        opts.swappingallowed = (GetControlItemValue(mydlg, 6) != 0);
                                                        GetControlItemTitle(mydlg, 7, opts.swapfile);
                                                        
                                                        DisposeDialog(mydlg);
                                                        return 0;
                                                }
                                                
                                                case 5:   /* Quit button */
                                                        DisposeDialog(mydlg);
                                                        return(1);
                                        }
                                }
                        }
                }
                else if (gotevent)
                {
                        switch (myEvent.what)
                        {
                                case mouseDown:
                                        switch (FindWindow(myEvent.where, &whichWindow))
                                        {
                                                case inDesk: 
                                                        SysBeep(10);
                                                        break;
                                        
                                                case inGoAway:
                                                        break;

                                                case inMenuBar:
                                                        DoCommand(MenuSelect(myEvent.where));
                                                        SetPort((WindowPtr)mydlg);
                                                        break;

                                                case inSysWindow:
                                                        SystemClick(&myEvent, whichWindow);
                                                        break;
                                        
                                                case inDrag:
                                                        if (whichWindow == (WindowPtr)mydlg)
                                                        {
                                                                static Rect dragRect = { 0, 0, 1024, 1024 };
                                                        
                                                                /* oldfront = whichWindow; */
                                                                DragWindow(whichWindow, myEvent.where, &dragRect);
                                                        }
                                                        break;
                                        
                                                case inContent:
                                                        if (whichWindow != myWindow && whichWindow != FrontWindow())
                                                                SelectWindow(whichWindow);
                                                        break;
                                        
                                                case inGrow:
                                                        break;

                                                default:
                                                        break;
                                        }
                                        break;
                                
                                case activateEvt:
                                {
                                        Rect r;
                                        extern TEHandle TEH;
                                        extern ControlHandle vScroll;
        
                                        if (ours(whichWindow = (WindowPtr)myEvent.message))
                                        {
                                                r = whichWindow->portRect;
                                                r.top = r.bottom - (kScrollBarWidth+1);
                                                r.left = r.left - (kScrollBarWidth+1);
                                                InvalRect(&r);
                                                if ( myEvent.modifiers & activeFlag )
                                                {
                                                        TEActivate( TEH );
                                                        ShowControl( vScroll );
                                                        TEFromScrap();
                                                }
                                                else
                                                {
                                                        TEDeactivate(TEH);
                                                        HideControl( vScroll );
                                                        ZeroScrap();
                                                        TEToScrap();
                                                }
                                        }
                                        break;
                                }
                                break;
                                
                                case updateEvt:
                                        if (ours(whichWindow = (WindowPtr)myEvent.message))
                                                UpdateWindow(whichWindow);
                                        break;
                                
                                case keyDown:
                                case autoKey:
                                        break;
                        }
                }
        }
}



static FSSpec gsGameFile = { 0, 0L, "\p" };
static FSSpec gsSaveFile = { 0, 0L, "\p" };

const OSType kGameFileType = 'TADG';
const OSType kSaveFileType = 'TADV';

inline bool empty(const FSSpec &fs)
        { return StrLength(fs.name) == 0; }


OSErr HandleOpenApp()
{
        // No special action needed.
        return noErr;
}

OSErr HandleOpenDocument(const FSSpec *doc)
{
        FInfo   fInfo;
        
        FSpGetFInfo(doc, &fInfo);
        if (fInfo.fdType == kGameFileType) {
                //DPRINTF(("Got a game file: %.*s", doc->name[0], &doc->name[1]));
                gsGameFile = *doc;
                return noErr;
        }
        else if (fInfo.fdType == kSaveFileType) {
                //DPRINTF(("Got a save file: %.*s", doc->name[0], &doc->name[1]));
                gsSaveFile = *doc;
                return noErr;
        }
        else {
                DPRINTF(("Got document of type %.4s -- not handled.\n", &fInfo.fdType));
                return errAEEventNotHandled;
        }
}



static bool hitOptions;
static bool showingAllFiles;
static bool noOptions;

static pascal Boolean myFilter(CInfoPBRec *parm)
{
        if (showingAllFiles)
                return false;
        else
                return (parm->hFileInfo.ioFlFndrInfo.fdType == 'TADG') ? 0 : -1;
}

static pascal short gamehook(short item, DialogPtr dlg)
{
        static bool refresh_list;
        
        /* set buttons on first call */
        if (item == -1)
        {
                SetControlItemValue(dlg, 12, showingAllFiles ? 0 : 1);
                SetControlItemValue(dlg, 13, showingAllFiles ? 1 : 0);
                if (noOptions)
                        HideDialogItem(dlg, 11);
        }
        else if (item == 11 && !noOptions)
        {
                hitOptions = true;
                item = 1;
        }
        else if ((item == 12 && showingAllFiles) || (item == 13 && !showingAllFiles))
        {
                /* switch to new showing-all-files status */
                showingAllFiles = !showingAllFiles;
                
                /* update the radio buttons */
                SetControlItemValue(dlg, 12, showingAllFiles ? 0 : 1);
                SetControlItemValue(dlg, 13, showingAllFiles ? 1 : 0);
                
                /* queue a list refresh */
                item = 101;
                //refresh_list = TRUE;
        }
        else if (item == 100 && refresh_list)
        {
                /* refresh the list on idle */
                item = 101;
                refresh_list = false;
        }
        return item;
}

static int __getgamefile(Str255 gamefile)
{
        Point                   sfgWhere = { 90, 82 };
        SFReply                 reply;
        SInt16                  typcnt;
        SFTypeList              myTypes;
        FileFilterUPP   myFilterUPP;
        DlgHookUPP              gamehookUPP;
        
        myFilterUPP = NewFileFilterProc(myFilter);
        gamehookUPP = NewDlgHookProc(gamehook);
        if (!myFilter || !gamehookUPP) return 1;
        
        hitOptions = false;
        myTypes[0] = 'TADG';
        typcnt = -1;
        showingAllFiles = false;
        
        SFPGetFile(sfgWhere, "\pSelect Game", myFilterUPP, typcnt, myTypes, gamehookUPP, &reply, 129, NULL);
        DisposeRoutineDescriptor(myFilterUPP);
        DisposeRoutineDescriptor(gamehookUPP);
        
        if (hitOptions) {
                assert(!noOptions);
                return 0;
        }
        else if (reply.good) {
                if (VRefToPath(reply.vRefNum, gamefile) != noErr) return 1;
                StringCat_pp(gamefile, reply.fName, sizeof(Str255));
                gsGameFile.vRefNum = reply.vRefNum;
                StringCopy_pp(gsGameFile.name, reply.fName, sizeof(gsGameFile.name));
                return 0;
        }
        else
                return 1;
}

static int getgamefile(Str255 gamefile)
{
        noOptions = true;
        return __getgamefile(gamefile);
}

static int getgamefile(tropts_t &opts)
{
        noOptions = false;
        if (__getgamefile(opts.gamefile) == 0) {
                if (hitOptions)
                        return os0getopt(opts);
                else
                        return 0;
        }
        else
                return 1;
}


static void CheckForLaunchAppleEvents()
{
        const int       kMaxNullEvents = 15;
        int                     nulls = 0;
        EventRecord     ev;
        
        while (nulls < kMaxNullEvents) {
                WaitNextEvent(highLevelEventMask, &ev, 1, NULL);
                switch (ev.what) {
                        case kHighLevelEvent:
                                //DPRINTF(("CheckForLaunchAppleEvents: got one after %d null events!", nulls));
                                (void) AEProcessAppleEvent(&ev);
                                return;
                        case nullEvent:
                                nulls++;
                                break;
                }
        }
        DPRINTF(("CheckForLaunchAppleEvents: Exited without getting an event!"));
}

static bool HasAttachedGameFile()
{
        osfildef   *fp;

        fp = os_exeseek(NULL, "TGAM");
        if (fp) {
                /* Got a real file descriptor, make sure it's not empty. */
                ulong   curpos, endpos;
                
        curpos = osfpos(fp);
        osfseek(fp, 0L, OSFSK_END);
        endpos = osfpos(fp);
                osfcls(fp);
        //      return curpos != endpos;
                if (curpos == endpos)
                        return false;
                else
                        return true;
        }
        else
                return false;
}

void main()
{
        if (InitToolbox() == noErr) {
                Str255          appName;
                StringPtr       gameName;
                
                (void) GetApplicationInfo(appName, NULL);
                
                /* Check for our first AppleEvent to see if we were opened with some files. */
                CheckForLaunchAppleEvents();
                
                if (os_init(NULL, NULL, NULL, NULL, 0) == 0) {
                        int             argc = 0;
                        char   *argv[20] = { NULL };
                        char    argbuf[1024] = "";
                        bool    failed = false;
                        
                        /* Build a command line with a game file to pass to trdmain.
                        */
                        tropts_t        opts;
                        
                        if (HasAttachedGameFile()) {
                                // If this is a stand-alone game, always use the attached file.
                                assert(empty(gsGameFile)); // XXX: Put a real error alert here.
                                gameName = appName;
                        }
                        else {
                                // Read baseline options from our preferences file.
                                getconfig(NULL, opts);
                                
                                // If we got a game from the Finder, use that; otherwise get one (with options).
                                if (empty(gsGameFile))
                                        failed = (getgamefile(opts) != 0);
                                else
                                        FSSpecToPath(&gsGameFile, opts.gamefile);
                                
                                gameName = gsGameFile.name;
                        }
                        
                        /* If we got a saved game, handle it as a -r option. */
                        if (!empty(gsSaveFile))
                                FSSpecToPath(&gsSaveFile, opts.savefile);
                        
                        /* Run the game!
                        */
                        if (!failed) {
                                int                                     argc = 0;
                                char                       *argv[20] = { NULL };
                                char                            argbuf[1024] = "";
                                extern WindowPtr        gameWindow;
                                
                                if (gameWindow) SetWTitle(gameWindow, gameName);
                                writecommandline(opts, wrtoptargv_t(argbuf, argc, argv), false);
                                os0main2(argc, argv, trdmain, "", "" /*"config.tr"*/, NULL);
                                os_expause();
                        }

                        /* uninitialize the os layer */
                        os_uninit();
                }
        }
        XXX_FixStandAlone();
}

/* malloc and free */
#include <stdlib.h>

void *osmalloc(size_t size)
{
        return malloc(size);
}

void osfree(void *block)
{
        free(block);
}

int topEvent(DialogPtr mydlg, ListHandle mylist)
{
        return 1;
}

