/*
==========================================================================================

	File:		mac_tdb.r

	Contains:	Resources for TADS Debugger.

	Copyright:	 1998 by Christopher Nebel, all rights reserved.

	Change History (most recent first):
	
		<3>		 9/22/98	Neb		Add resources from binary file.
		<2>		 8/26/98	Neb		Use new common.r.
		<1>		 7/21/98	Neb		Initial checkin.

==========================================================================================
*/

#define SystemSevenOrLater 1
#define IncludeSIZE 0

#include <Types.r>
#include <Dialogs.r>
#include <Menus.r>
#include <Icons.r>
#if IncludeSIZE
#include <Processes.r>
#endif


#define TADS_COMPONENT  "Debugger"

#include "common.r"

// =======================================================================================
// == Signature and size.
// ==

type 'TADD' as 'STR ';

resource 'TADD' (0) {
	"TADS: The Text Adventure Development System " TADSLEVEL
};

#if IncludeSIZE
/* CodeWarrior builds a SIZE(-1) resource for us. */
resource 'SIZE' (-1) {
	reserved,
	acceptSuspendResumeEvents,
	reserved,
	canBackground,
	needsActivateOnFGSwitch,
	backgroundAndForeground,
	dontGetFrontClicks,
	ignoreChildDiedEvents,
	is32BitCompatible,
	isHighLevelEventAware,
	localAndRemoteHLEvents,
	notStationeryAware,
	dontUseTextEditServices,
	reserved,
	reserved,
	reserved,
	1024 * 1024,
	1024 * 1024
};
#endif

// =======================================================================================
// == Dialog, alert, and window resources.
// ==

// ...............................................
// .. Confirm quit.

resource 'ALRT' (12079) {
	{164, 168, 274, 416},
	12079,
	{	/* array: 4 elements */
		/* [1] */
		OK, visible, sound1,
		/* [2] */
		OK, visible, sound1,
		/* [3] */
		OK, visible, sound1,
		/* [4] */
		OK, visible, sound1
	},
	alertPositionMainScreen
};

resource 'DITL' (12079) {
	{	/* array DITLarray: 3 elements */
		/* [1] */
		{62, 93, 82, 153},
		Button {
			enabled,
			"Yes"
		},
		/* [2] */
		{62, 163, 82, 223},
		Button {
			enabled,
			"No"
		},
		/* [3] */
		{24, 99, 45, 209},
		StaticText {
			disabled,
			"Really Quit TDB?"
		}
	}
};

// ...............................................
// .. Generic alert.

resource 'ALRT' (12370) {
	{166, 204, 270, 446},
	12370,
	{	/* array: 4 elements */
		/* [1] */
		OK, visible, sound1,
		/* [2] */
		OK, visible, sound1,
		/* [3] */
		OK, visible, sound1,
		/* [4] */
		OK, visible, sound1
	},
	alertPositionMainScreen
};

resource 'DITL' (12370) {
	{	/* array DITLarray: 2 elements */
		/* [1] */
		{61, 118, 81, 178},
		Button {
			enabled,
			"OK"
		},
		/* [2] */
		{27, 66, 52, 238},
		StaticText {
			disabled,
			"^0"
		}
	}
};

// ...............................................
// .. About TADS.

resource 'DLOG' (7768) {
	{100, 142, 316, 512},
	dBoxProc,
	visible,
	noGoAway,
	0x0,
	7768,
	"About TADS",
	alertPositionMainScreen
};

resource 'DITL' (7768) {
	{	/* array DITLarray: 6 elements */
		/* [1] */
		{185, 158, 205, 218},
		Button {
			enabled,
			"OK"
		},
		/* [2] */
		{33, 55, 56, 327},
		StaticText {
			disabled,
			"The Text Adventure Development System\n"
		},
		/* [3] */
		{10, 152, 29, 214},
		StaticText {
			disabled,
			"TADS 2.2"
		},
		/* [4] */
		{119, 35, 141, 346},
		StaticText {
			disabled,
			"Copyright  1990-98 by Michael J. Roberts."
		},
		/* [5] */
		{57, 129, 78, 250},
		StaticText {
			disabled,
			"Source Debugger"
		},
		/* [6] */
		{144, 124, 166, 263},
		StaticText {
			disabled,
			"All Rights Reserved."
		}
	}
};

// ...............................................
// .. Select folder (obsolete).

#if 0
resource 'DLOG' (1313, purgeable) {
	{0, 0, 238, 356},
	dBoxProc,
	invisible,
	noGoAway,
	0x0,
	1313,
	"",
	alertPositionMainScreen
};

resource 'DITL' (1313, purgeable) {
	{	/* array DITLarray: 11 elements */
		/* [1] */
		{138, 256, 156, 336},
		Button {
			enabled,
			"Open"
		},
		/* [2] */
		{0, 699, 80, 717},
		Button {
			enabled,
			""
		},
		/* [3] */
		{163, 256, 181, 336},
		Button {
			enabled,
			"Cancel"
		},
		/* [4] */
		{39, 232, 59, 347},
		UserItem {
			disabled
		},
		/* [5] */
		{68, 256, 86, 336},
		Button {
			enabled,
			"Eject"
		},
		/* [6] */
		{93, 256, 111, 336},
		Button {
			enabled,
			"Drive"
		},
		/* [7] */
		{39, 12, 185, 229},
		UserItem {
			enabled
		},
		/* [8] */
		{39, 229, 185, 246},
		UserItem {
			enabled
		},
		/* [9] */
		{124, 252, 125, 340},
		UserItem {
			disabled
		},
		/* [10] */
		{0, 660, 101, 756},
		StaticText {
			disabled,
			""
		},
		/* [11] */
		{193, 46, 214, 195},
		Button {
			enabled,
			"Select Current Folder"
		}
	}
};
#endif

// ...............................................
// .. Memory settings.

resource 'DLOG' (13919) {
	{110, 90, 314, 336},
	documentProc,
	visible,
	goAway,
	0x0,
	13919,
	"Memory Settings",
	staggerMainScreen
};

resource 'DITL' (13919) {
	{	/* array DITLarray: 8 elements */
		/* [1] */
		{39, 10, 61, 151},
		StaticText {
			enabled,
			"Parse memory pool:"
		},
		/* [2] */
		{39, 160, 59, 220},
		EditText {
			disabled,
			"6192"
		},
		/* [3] */
		{75, 10, 98, 151},
		StaticText {
			disabled,
			"Local symbol table:"
		},
		/* [4] */
		{76, 160, 96, 220},
		EditText {
			disabled,
			"2048"
		},
		/* [5] */
		{109, 10, 131, 150},
		StaticText {
			disabled,
			"Run-time stack:"
		},
		/* [6] */
		{109, 160, 129, 220},
		EditText {
			disabled,
			"50"
		},
		/* [7] */
		{145, 10, 168, 144},
		StaticText {
			disabled,
			"Run-time heap:"
		},
		/* [8] */
		{146, 160, 166, 220},
		EditText {
			disabled,
			"1024"
		}
	}
};

// ...............................................
// .. Find

resource 'DLOG' (14306) {
	{126, 106, 234, 362},
	dBoxProc,
	visible,
	noGoAway,
	0x0,
	14306,
	"Find...",
	alertPositionMainScreen
};

resource 'DITL' (14306) {
	{	/* array DITLarray: 4 elements */
		/* [1] */
		{80, 53, 100, 113},
		Button {
			enabled,
			"OK"
		},
		/* [2] */
		{80, 129, 100, 189},
		Button {
			enabled,
			"Cancel"
		},
		/* [3] */
		{12, 5, 29, 116},
		StaticText {
			disabled,
			"Find text:"
		},
		/* [4] */
		{38, 8, 59, 245},
		EditText {
			disabled,
			""
		}
	}
};

// ...............................................
// .. Enter condition.

resource 'DLOG' (14843) {
	{102, 68, 228, 320},
	dBoxProc,
	visible,
	noGoAway,
	0x0,
	14843,
	"Enter Condition",
	alertPositionMainScreen
};

resource 'DITL' (14843) {
	{	/* array DITLarray: 4 elements */
		/* [1] */
		{90, 53, 110, 113},
		Button {
			enabled,
			"OK"
		},
		/* [2] */
		{90, 129, 110, 189},
		Button {
			enabled,
			"Cancel"
		},
		/* [3] */
		{18, 5, 36, 211},
		StaticText {
			disabled,
			"Enter Expression:"
		},
		/* [4] */
		{49, 7, 69, 244},
		EditText {
			disabled,
			""
		}
	}
};

// ...............................................
// .. Settings window.

resource 'DLOG' (19587) {
	{50, 5, 322, 500},
	documentProc,
	visible,
	noGoAway,
	0x0,
	19587,
	"TADS Debugger v2.2",
	staggerMainScreen
};

resource 'DITL' (19587) {
	{	/* array DITLarray: 18 elements */
		/* [1] */
		{10, 133, 31, 407},
		StaticText {
			disabled,
			""
		},
		/* [2] */
		{11, 12, 30, 120},
		StaticText {
			disabled,
			"Game to Debug:"
		},
		/* [3] */
		{10, 412, 31, 478},
		Button {
			enabled,
			"Select"
		},
		/* [4] */
		{40, 12, 58, 131},
		StaticText {
			disabled,
			"Source folders:"
		},
		/* [5] */
		{40, 133, 144, 407},
		UserItem {
			enabled
		},
		/* [6] */
		{63, 412, 83, 478},
		Button {
			enabled,
			"Add"
		},
		/* [7] */
		{93, 412, 113, 478},
		Button {
			enabled,
			"Remove"
		},
		/* [8] */
		{240, 341, 261, 409},
		Button {
			enabled,
			"OK"
		},
		/* [9] */
		{240, 417, 261, 484},
		Button {
			enabled,
			"Quit"
		},
		/* [10] */
		{153, 12, 171, 146},
		CheckBox {
			enabled,
			"Allow Swapping"
		},
		/* [11] */
		{177, 89, 198, 338},
		StaticText {
			disabled,
			"<Default>"
		},
		/* [12] */
		{177, 12, 199, 85},
		StaticText {
			disabled,
			"Swap File:"
		},
		/* [13] */
		{177, 412, 198, 478},
		Button {
			enabled,
			"Select"
		},
		/* [14] */
		{210, 12, 229, 156},
		StaticText {
			disabled,
			"Maximum Cache Size:"
		},
		/* [15] */
		{209, 166, 230, 257},
		EditText {
			disabled,
			""
		},
		/* [16] */
		{0, 655, 21, 928},
		CheckBox {
			enabled,
			"Version 1 Compatibility Mode"
		},
		/* [17] */
		{240, 250, 261, 332},
		Button {
			enabled,
			"Memory"
		},
		/* [18] */
		{177, 342, 198, 408},
		Button {
			enabled,
			"Default"
		}
	}
};

// ...............................................
// .. Delete breakpoint.

resource 'DLOG' (23200) {
	{70, 66, 262, 322},
	dBoxProc,
	visible,
	noGoAway,
	0x0,
	23200,
	"Delete Breakpoint",
	centerMainScreen
};

resource 'DITL' (23200) {
	{	/* array DITLarray: 3 elements */
		/* [1] */
		{63, 181, 83, 241},
		Button {
			enabled,
			"Done"
		},
		/* [2] */
		{94, 181, 114, 241},
		Button {
			enabled,
			"Delete"
		},
		/* [3] */
		{7, 10, 185, 173},
		UserItem {
			enabled
		}
	}
};

// ...............................................
// .. Evaluate.

resource 'DLOG' (25121) {
	{124, 78, 252, 302},
	dBoxProc,
	visible,
	goAway,
	0x0,
	25121,
	"Evaluate",
	alertPositionMainScreen
};

resource 'DITL' (25121) {
	{	/* array DITLarray: 4 elements */
		/* [1] */
		{89, 48, 109, 108},
		Button {
			enabled,
			"OK"
		},
		/* [2] */
		{89, 118, 109, 178},
		Button {
			enabled,
			"Cancel"
		},
		/* [3] */
		{14, 12, 33, 101},
		StaticText {
			disabled,
			"Expression:"
		},
		/* [4] */
		{44, 12, 65, 211},
		EditText {
			disabled,
			""
		}
	}
};

// ...............................................
// .. Set breakpoint.

resource 'DLOG' (26375) {
	{60, 52, 212, 324},
	dBoxProc,
	visible,
	noGoAway,
	0x0,
	26375,
	"Set Breakpoint",
	alertPositionMainScreen
};

resource 'DITL' (26375) {
	{	/* array DITLarray: 6 elements */
		/* [1] */
		{123, 59, 143, 119},
		Button {
			enabled,
			"Set"
		},
		/* [2] */
		{123, 134, 143, 194},
		Button {
			enabled,
			"Cancel"
		},
		/* [3] */
		{5, 9, 22, 192},
		StaticText {
			disabled,
			"Function or Object.Method:"
		},
		/* [4] */
		{28, 7, 48, 257},
		EditText {
			disabled,
			""
		},
		/* [5] */
		{59, 9, 76, 80},
		StaticText {
			disabled,
			"Condition:"
		},
		/* [6] */
		{82, 7, 102, 257},
		EditText {
			disabled,
			""
		}
	}
};

// ...............................................
// .. Window resources.

resource 'WIND' (128) {
	{40, 2, 265, 512},
	documentProc,
	visible,
	noGoAway,
	0x0,
	"TADS Game Window",
	noAutoCenter
};

resource 'WIND' (12075) {
	{287, 2, 425, 250},
	documentProc,
	visible,
	noGoAway,
	0x0,
	"TDB Command Window",
	noAutoCenter
};

resource 'WIND' (19676) {
	{287, 250, 425, 512},
	documentProc,
	visible,
	noGoAway,
	0x0,
	"Source",
	noAutoCenter
};

resource 'WIND' (25553) {
	{48, 336, 158, 524},
	documentProc,
	visible,
	noGoAway,
	0x0,
	"Watch Expressions",
	noAutoCenter
};

// =======================================================================================
// == Menus.
// ==

resource 'MENU' (128) {
	128,
	textMenuProc,
	allEnabled,
	enabled,
	apple,
	{
		"About TADS", noIcon, noKey, noMark, plain,
		"-", noIcon, noKey, noMark, plain
	}
};

resource 'MENU' (129) {
	129,
	textMenuProc,
	0x7FFFFFF7,
	enabled,
	"File",
	{
		"Quit", noIcon, "Q", noMark, plain
	}
};

resource 'MENU' (130) {
	130,
	textMenuProc,
	0x7FFFFFBD,
	enabled,
	"Edit",
	{
		"Undo", noIcon, "Z", noMark, plain,
		"-", noIcon, noKey, noMark, plain,
		"Cut", noIcon, "X", noMark, plain,
		"Copy", noIcon, "C", noMark, plain,
		"Paste", noIcon, "V", noMark, plain,
		"Clear", noIcon, noKey, noMark, plain,
		"-", noIcon, noKey, noMark, plain,
		"Find", noIcon, "F", noMark, plain,
		"Find Again", noIcon, "A", noMark, plain
	}
};

resource 'MENU' (131) {
	131,
	textMenuProc,
	allEnabled,
	enabled,
	"Execution",
	{
		"Go", noIcon, "G", noMark, plain,
		"Step In", noIcon, "T", noMark, plain,
		"Step Over", noIcon, "P", noMark, plain,
		"Stop", noIcon, noKey, noMark, plain,
		"Record history", noIcon, noKey, noMark, plain,
		"Show history", noIcon, noKey, noMark, plain,
		"Clear history", noIcon, noKey, noMark, plain
	}
};

resource 'MENU' (132) {
	132,
	textMenuProc,
	allEnabled,
	enabled,
	"Data",
	{
		"Evaluate", noIcon, "E", noMark, plain,
		"Stack", noIcon, "K", noMark, plain,
		"Up Stack", noIcon, "U", noMark, plain,
		"Down Stack", noIcon, "D", noMark, plain
	}
};

resource 'MENU' (133) {
	133,
	textMenuProc,
	allEnabled,
	enabled,
	"Breakpoint",
	{
		"Set", noIcon, "B", noMark, plain,
		"Clear", noIcon, noKey, noMark, plain,
		"Disable", noIcon, noKey, noMark, plain,
		"Enable", noIcon, noKey, noMark, plain,
		"List", noIcon, noKey, noMark, plain
	}
};

resource 'MENU' (134) {
	134,
	textMenuProc,
	allEnabled,
	enabled,
	"Source",
	{
		"View Module", noIcon, noKey, noMark, plain,
		"View File", noIcon, noKey, noMark, plain,
		"Current Line", noIcon, noKey, noMark, plain
	}
};

resource 'MENU' (135) {
	135,
	textMenuProc,
	allEnabled,
	enabled,
	"Watch",
	{
		"Set", noIcon, noKey, noMark, plain
	}
};

// =======================================================================================
// == BNDL and FREF resources.
// ==

resource 'BNDL' (128) {
	'TADD',
	0,
	{
		'FREF',
		{
			0, 128,
			1, 130,
			2, 131
		},
		
		'ICN#',
		{
			0, 128,
			1, 130,
			2, 131
		}
	}
};

resource 'FREF' (128) {
	'APPL',
	0,
	""
};

resource 'FREF' (130) {
	'TEXT',
	1,
	""
};

resource 'FREF' (131) {
	'SWAP',
	2,
	""
};

// =======================================================================================
// == Icons.
// ==

// ---------------------------------------------------------------------------------------
// -- Large icons.

// ...............................................
// .. ICN#

resource 'ICN#' (128, purgeable) {
	{	/* array: 2 elements */
		/* [1] */
		$"0000 0000 0000 0000 FFFF FFF8 8000 0008"
		$"8F91 C708 8229 281C 8229 263C 827D 215C"
		$"8245 CE98 8000 0138 FFFF DE68 8000 24C8"
		$"8010 49C8 8020 9328 8061 2618 8042 4E08"
		$"80F2 9A07 87F1 7C07 8DFE 8007 91FA E007"
		$"8077 9C07 804D 23C7 8044 103F 8C22 5E0F"
		$"8765 0D08 81E0 8988 8012 4808 8038 3808"
		$"8066 2008 8083 E008 8082 0008 FFFF FFF8",
		/* [2] */
		$"0000 0000 0000 0000 FFFF FFF8 FFFF FFF8"
		$"FFFF FFF8 FFFF FFFC FFFF FFFC FFFF FFFC"
		$"FFFF FFF8 FFFF FFF8 FFFF FFF8 FFFF FFF8"
		$"FFFF FFF8 FFFF FFF8 FFFF FFF8 FFFF FFF8"
		$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
		$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
		$"FFFF FFF8 FFFF FFF8 FFFF FFF8 FFFF FFF8"
		$"FFFF FFF8 FFFF FFF8 FFFF FFF8 FFFF FFF8"
	}
};

resource 'ICN#' (130) {
	{	/* array: 2 elements */
		/* [1] */
		$"FFFF F800 8000 0C00 BE47 1A00 88A4 A900"
		$"88A4 9880 89F4 8840 8917 3FE0 8000 0020"
		$"FFFF FFE0 8000 0020 8000 0020 8780 0020"
		$"8841 0020 9322 2020 97A6 3020 97A4 1020"
		$"932C 1020 887F 6F20 87D4 1060 8119 F9A0"
		$"8006 8F20 8785 1420 8844 4220 9020 2660"
		$"9036 51A0 9028 08A0 9027 6F30 8842 82BC"
		$"8786 703F 8008 2A3F 8008 203C FFFF FFF0",
		/* [2] */
		$"FFFF F800 FFFF FC00 FFFF FE00 FFFF FF00"
		$"FFFF FF80 FFFF FFC0 FFFF FFE0 FFFF FFE0"
		$"FFFF FFE0 FFFF FFE0 FFFF FFE0 FFFF FFE0"
		$"FFFF FFE0 FFFF FFE0 FFFF FFE0 FFFF FFE0"
		$"FFFF FFE0 FFFF FFE0 FFFF FFE0 FFFF FFE0"
		$"FFFF FFE0 FFFF FFE0 FFFF FFE0 FFFF FFE0"
		$"FFFF FFE0 FFFF FFE0 FFFF FFF0 FFFF FFFC"
		$"FFFF FFFF FFFF FFFF FFFF FFFC FFFF FFF0"
	}
};

resource 'ICN#' (131) {
	{	/* array: 2 elements */
		/* [1] */
		$"FFFF F800 8000 0C00 BE47 1A00 88A4 A900"
		$"88A4 9880 89F4 8840 8917 3FE0 8000 0020"
		$"FFFF FFE0 8000 0020 8000 0020 8001 0020"
		$"8006 8020 8005 C020 801B E020 8017 F020"
		$"806F D820 805F B020 81BF 7820 817E D820"
		$"86FD F820 86FB 6820 8777 E020 87AD A020"
		$"85DF 8020 84F6 8020 807E 0030 802A 003C"
		$"8008 003F 8008 003F 8000 003C FFFF FFF0",
		/* [2] */
		$"FFFF F800 FFFF FC00 FFFF FE00 FFFF FF00"
		$"FFFF FF80 FFFF FFC0 FFFF FFE0 FFFF FFE0"
		$"FFFF FFE0 FFFF FFE0 FFFF FFE0 FFFF FFE0"
		$"FFFF FFE0 FFFF FFE0 FFFF FFE0 FFFF FFE0"
		$"FFFF FFE0 FFFF FFE0 FFFF FFE0 FFFF FFE0"
		$"FFFF FFE0 FFFF FFE0 FFFF FFE0 FFFF FFE0"
		$"FFFF FFE0 FFFF FFE0 FFFF FFF0 FFFF FFFC"
		$"FFFF FFFF FFFF FFFF FFFF FFFC FFFF FFF0"
	}
};

// ...............................................
// .. icl4

resource 'icl4' (128) {
	$"0000 0000 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 0000"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF F000"
	$"F000 0000 0000 0000 0000 0000 0000 F000"
	$"F000 FFFF F00F 000F FF00 CFFF 0000 F000"
	$"F000 00F0 00E0 E00F 0CF0 F000 000F FF00"
	$"F000 00F0 0CF0 FC0F 00F0 CFFC 00F4 4F00"
	$"F000 00F0 0EFF FE0F 0CF0 000F 0F1F 3F00"
	$"F000 00F0 CF00 0FCF FF00 FFFC F12F F000"
	$"F000 0000 0000 0000 0000 000F 12FF F000"
	$"FFFF FFFF FFFF FFFF FFCF FFF1 2FFC F000"
	$"F000 0000 0000 0000 00F0 DF12 FF0C F000"
	$"F000 0000 000F 0000 0FCD F12F FF0C F000"
	$"F000 0000 00F0 0000 F0DF 12FF DDFC F000"
	$"F000 0000 0FF0 000F CDF1 2FFD DD0F F000"
	$"F000 0000 0F00 00F0 DF12 FFFD D0C0 F000"
	$"F000 0000 FF33 00FD F12F FCFD 0C0C 0FFF"
	$"F000 0FFF FFF3 000F 1FFF FFC0 C0C0 DFFF"
	$"F000 FF03 FFFF FFF1 FC0C 0C0C 0C0C DFFF"
	$"F00F 0003 3FFF E8F2 FFFD DDD0 C0C0 DFFF"
	$"F000 0000 0FEE EFFF ADDF FFDD DD0C DFFF"
	$"F000 0000 0F7E EF8E 8DF0 00FF FFDD DFFF"
	$"F000 0000 0F78 8E88 88DF 0000 00FF FFFF"
	$"F000 FF00 00F7 88E8 8EDF FFF0 0000 FFFF"
	$"F000 0FFF 0FF7 8E8E 888D FF0F 0000 F000"
	$"F000 0CCF FFF7 8888 E88D FC0F F000 F000"
	$"F000 000C CCCF 78E8 8E8D FC00 CC00 F000"
	$"F000 0000 00FF F778 88FF FC00 0000 F000"
	$"F000 0000 0FFC CFF7 88FC CC00 0000 F000"
	$"F000 0000 FCC0 00FF FFFC 0000 0000 F000"
	$"F000 0000 FC00 00FC CCCC 0000 0000 F000"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF F0"
};

resource 'icl4' (130) {
	$"FFFF FFFF FFFF FFFF FFFF F000 0000 0000"
	$"F000 0000 0000 0000 0000 FF00 0000 0000"
	$"F0FF FFF0 0F00 0FFF 00CF FCF0 0000 0000"
	$"F000 F000 E0E0 0F0C F0F0 F0CF 0000 0000"
	$"F000 F00C F0FC 0F00 F0CF F00C F000 0000"
	$"F000 F00E FFFE 0F0C F000 F0CC CF00 0000"
	$"F000 F0CF 000F CFFF 00FF FFFF FFF0 0000"
	$"F000 0000 0000 0000 0000 0DDD DDF0 0000"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFF0 0000"
	$"F000 0000 0000 0000 0000 0000 0CF0 0000"
	$"F000 0000 0000 0000 0000 0000 0CF0 0000"
	$"F000 0AFF A000 0000 0000 0000 0CF0 0000"
	$"F000 AEEE DA00 000C 0000 0000 0CF0 0000"
	$"F00A EEAA DCF0 00C0 00C0 0000 0CF0 0000"
	$"F00F EAFF ACF0 0CC0 00CC 0000 0CF0 0000"
	$"F00F EAFF ACF0 0C00 000C C000 0CF0 0000"
	$"F00A DDAA C0F0 CC44 000C C000 0CF0 0000"
	$"F000 ACCC 0ACC CFFF 0FF0 FFFF 0CF0 0000"
	$"F000 0AFF FC04 CCCC CC0C CC00 0DF0 0000"
	$"F000 000C 0004 4CC8 C8CC CC0C CCF0 0000"
	$"F000 0000 0000 0C8C 8C8C 8CCC CCF0 0000"
	$"F000 0AFF A000 0CC8 C8C8 C8CC 0CF0 0000"
	$"F000 AC00 CA00 0C8C 8C8C 8C8C 0CF0 0000"
	$"F00A C00C CCF0 00C8 C8C8 C8CC CCF0 0000"
	$"F00F 00CC CCFC 0CCC 8C8C 8C8C CCF0 0000"
	$"F00F 0CCC CDFC CCC8 C8C8 C8C8 CCF0 0000"
	$"F00A CCCC DDFC CFFF 8FFC FFFF CCFE 0000"
	$"F000 ACCD DA00 00CC C8C8 C8CC CCFE EE00"
	$"F000 0AFF F000 0CCC CCCC 8CCC CCFE EEEE"
	$"F000 0000 0000 CCC0 00CC CCCC 0CFE EEEE"
	$"F000 0000 0000 CC00 00CC CCCC 0CFE EE00"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFE"
};

resource 'icl4' (131) {
	$"FFFF FFFF FFFF FFFF FFFF F000 0000 0000"
	$"F000 0000 0000 0000 0000 FF00 0000 0000"
	$"F0FF FFF0 0F00 0FFF 00CF FCF0 0000 0000"
	$"F000 F000 E0E0 0F0C F0F0 F0CF 0000 0000"
	$"F000 F00C F0FC 0F00 F0CF F00C F000 0000"
	$"F000 F00E FFFE 0F0C F000 F0CC CF00 0000"
	$"F000 F0CF 000F CFFF 00FF FFFF FFF0 0000"
	$"F000 0000 0000 0000 0000 0CCC CCF0 0000"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFF0 0000"
	$"F000 0000 0000 0000 0000 0000 0CF0 0000"
	$"F000 0000 0000 0000 0000 0000 0CF0 0000"
	$"F000 0000 0000 000D 0000 0000 0CF0 0000"
	$"F000 0000 0000 0DD0 D000 0000 0CF0 0000"
	$"F000 0000 0000 0F0D DD00 0000 0CF0 0000"
	$"F000 0000 000D D0DD DDD0 0000 0CF0 0000"
	$"F000 0000 000F 0DDD DDDD 0000 0CF0 0000"
	$"F000 0000 0DD0 DDDD DDCF F000 0CF0 0000"
	$"F000 0000 0F0D DDDD DCFF 0000 0CF0 0000"
	$"F000 000D D0DD DDDD CFFF D000 0CF0 0000"
	$"F000 000F 0DDD DDDC FF0E D000 0CF0 0000"
	$"F000 0DD0 DDDD DDCF FFDE D000 0CF0 0000"
	$"F000 0DFC DDDD DCFF 0ED0 D000 0CF0 0000"
	$"F000 0DFD CDDD CFFF DED0 0000 0CF0 0000"
	$"F000 0DFD DCDC FF0E D0D0 0000 0CF0 0000"
	$"F000 0D0F DDCF FFDE D000 0000 0CF0 0000"
	$"F000 0D00 FDDF 0ED0 D000 0000 0CF0 0000"
	$"F000 0000 0FDF DED0 0000 0000 0CFE 0000"
	$"F000 0000 00F0 D0D0 0000 0000 0CFE EE00"
	$"F000 0000 0000 D000 0000 0000 0CFE EEEE"
	$"F000 0000 0000 D000 0000 0000 0CFE EEEE"
	$"F000 0000 0000 0000 0000 0000 0CFE EE00"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFE"
};

// ...............................................
// .. icl8

resource 'icl8' (128) {
	$"0000 0000 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 0000"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FF00 0000"
	$"FF00 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 FF00 0000"
	$"FF00 F5F5 FFFF FFFF FFF5 F5FF F5F5 F5FF"
	$"FFFF F5F5 2BFF FFFF F5F5 F5F5 FF00 0000"
	$"FF00 F5F5 F5F5 FFF5 F5F5 FBF5 FBF5 F5FF"
	$"F52B FFF5 FFF5 F5F5 F5F5 F5FF FFFF 0000"
	$"FF00 F5F5 F5F5 FFF5 F5F6 FFF5 FFF6 F5FF"
	$"F5F5 FFF5 2BFF FF2B F5F5 FF13 13FF 0000"
	$"FF00 F5F5 F5F5 FFF5 F5FB FFFF FFFB F5FF"
	$"F52B FFF5 F5F5 F5FF F5FF 05FF D8FF 0000"
	$"FF00 F5F5 F5F5 FFF5 F6FF F5F5 F5FF F6FF"
	$"FFFF F5F5 FFFF FF2B FF05 33FF FF00 0000"
	$"FF00 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5FF 0533 FFFF FF00 0000"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF 2BFF FFFF FF05 33FF FF2B FF00 0000"
	$"FFF5 00F5 00F5 00F5 00F5 00F5 00F5 00F5"
	$"00F5 FF08 33FF 0533 FFFF F5F6 FF00 0000"
	$"FF00 F500 F500 F500 F500 F5FF F500 F500"
	$"F5FF 0833 FF05 33FF FFFF F5F6 FF00 0000"
	$"FFF5 00F5 00F5 00F5 00F5 FFF5 00F5 00F5"
	$"FF08 33FF 0533 FFFF 3333 FFF6 FF00 0000"
	$"FF00 F500 F500 F500 F5FF FF00 F500 F5FF"
	$"0833 FF05 33FF FF33 3333 08FF FF00 0000"
	$"FFF5 00F5 00F5 00F5 00FF 00F5 00F5 FF08"
	$"33FF 0533 FFFF FF33 3308 0808 FF00 0000"
	$"FF00 F500 F500 F500 FFFF D8D8 F500 FF33"
	$"FF05 33FF FFF8 FF33 0808 0808 08FF FFFF"
	$"FFF5 00F5 00FF FFFF FFFF FFD8 0000 00FF"
	$"05FF FFFF FFFF 0808 0808 0808 33FF FFFF"
	$"FF00 F500 FFFF F5D8 FFFF FFFF FFFF FF05"
	$"FF08 0808 0808 0808 0808 0808 33FF FFFF"
	$"FFF5 00FF 00F5 00D8 D8FF FFFF A5E3 FF33"
	$"FFFF FF33 3333 3308 0808 0808 33FF FFFF"
	$"FF00 F500 F500 F500 F5FF A5A5 A5FF FFFF"
	$"FDFA FAFF FFFF 3333 3333 0808 33FF FFFF"
	$"FFF5 00F5 00F5 00F5 00FF 92A5 A5FF E3A5"
	$"E39F FFF5 00F5 FFFF FFFF 3333 33FF FFFF"
	$"FF00 F500 F500 F500 F5FF 92E3 E3A5 E3E3"
	$"E3E3 9FFF F500 F500 F500 FFFF FFFF FFFF"
	$"FFF5 00F5 FFFF 00F5 0000 FF92 E3E3 A5E3"
	$"E3A5 9FFF FFFF FFF5 00F5 00F5 FFFF FFFF"
	$"FF00 F500 F5FF FFFF 00FF FF92 E3A5 E3A5"
	$"E3E3 E39F FFFF F5FF F500 F500 FF00 0000"
	$"FFF5 00F5 00F7 F7FF FFFF FF92 E3E3 E3E3"
	$"A5E3 E39F FFF7 00FF FFF5 00F5 FF00 0000"
	$"FF00 F500 F500 F5F7 F7F7 F7FF 92E3 A5E3"
	$"E3A5 E39F FFF7 F500 F7F7 F500 FF00 0000"
	$"FFF5 00F5 00F5 00F5 00F5 FFFF FF92 92E3"
	$"E3E3 FFFF FFF7 00F5 00F5 00F5 FF00 0000"
	$"FF00 F500 F500 F500 F5FF FFF7 F7FF FF92"
	$"E3E3 FFF7 F7F7 F500 F500 F500 FFF5 00F5"
	$"FFF5 00F5 00F5 00F5 FFF7 F700 0000 FFFF"
	$"FFFF FFF7 00F5 00F5 00F5 00F5 FFF5 F5F5"
	$"FF00 F500 F500 F500 FFF7 0000 0000 FFF7"
	$"F7F7 F7F7 F500 F500 F500 F500 FFF5 F5F5"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFF5 F5"
};

resource 'icl8' (130) {
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FF00 0000 0000 0000 0000 0000"
	$"FF00 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 FFFF 0000 0000 0000 0000 0000"
	$"FF00 FFFF FFFF FFF5 F5FF F5F5 F5FF FFFF"
	$"F5F5 2BFF FFF8 FF00 0000 0000 0000 0000"
	$"FF00 F5F5 FFF5 F5F5 FBF5 FBF5 F5FF F52B"
	$"FFF5 FFF5 FF00 F8FF 0000 0000 0000 0000"
	$"FF00 F5F5 FFF5 F5F6 FFF5 FFF6 F5FF F5F5"
	$"FFF5 2BFF FF00 00F8 FF00 0000 0000 0000"
	$"FF00 F5F5 FFF5 F5FB FFFF FFFB F5FF F52B"
	$"FFF5 F5F5 FFF5 F6F6 F8FF 0000 0000 0000"
	$"FF00 F5F5 FFF5 F6FF F5F5 F5FF F6FF FFFF"
	$"F5F5 FFFF FFFF FFFF FFFF FF00 0000 0000"
	$"FF00 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F9 F9F9 F9F9 FF00 0000 0000"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FFFF FF00 0000 0000"
	$"FF00 00F5 00F5 00F5 00F5 00F5 00F5 00F5"
	$"00F5 00F5 00F5 00F5 002B FF00 0000 0000"
	$"FF00 F500 F500 F500 F500 F500 F500 F500"
	$"F500 F500 F500 F500 F52B FF00 0000 0000"
	$"FF00 00F5 00FD FFFF FDF5 00F5 00F5 00F5"
	$"00F5 00F5 00F5 00F5 002B FF00 0000 0000"
	$"FF00 F500 FDFC FBFB FAFD 0000 F500 00F8"
	$"F500 F500 F500 F500 F52B FF00 0000 0000"
	$"FF00 00FD FCFB FDFD F9F8 FFF5 00F5 F8F5"
	$"00F5 F8F5 00F5 00F5 002B FF00 0000 0000"
	$"FF00 F5FF FBFD FFFF FDF7 FF00 F5F8 F800"
	$"F500 F8F8 F500 F500 F52B FF00 0000 0000"
	$"FF00 00FF FBFD FFFF FDF6 FFF5 00F8 00F5"
	$"00F5 00F8 F6F5 00F5 002B FF00 0000 0000"
	$"FF00 F5FD FAF9 FDFD F600 FF00 F8F8 1313"
	$"F500 F5F8 F800 F500 F52B FF00 0000 0000"
	$"FF00 00F5 FDF8 F7F6 00FD F8F8 F8FF FFFF"
	$"00FF FF00 FFFF FFFF 002B FF00 0000 0000"
	$"FF00 F500 F5FD FFFF FFF8 F513 F8F8 F8F8"
	$"F8F8 00F8 F8F6 F500 F5F9 FF00 0000 0000"
	$"FF00 00F5 00F5 00F8 00F5 0013 13F8 F8E3"
	$"E3E3 F8F8 F8F6 00F8 F82B FF00 0000 0000"
	$"FF00 F500 F500 F500 F500 F500 F5F8 E3E3"
	$"E392 9292 E3F8 F8F8 F62B FF00 0000 0000"
	$"FF00 00F5 00FD FFFF FDF5 00F5 00F8 92E3"
	$"E392 92E3 92E3 F8F6 002B FF00 0000 0000"
	$"FF00 F500 FDF6 F500 F6FD F500 F5F8 9292"
	$"92E3 9292 9292 E3F8 F52B FF00 0000 0000"
	$"FF00 00FD F6F5 00F6 2BF7 FFF5 00F5 F892"
	$"9292 E392 92E3 E3F8 F8F8 FF00 0000 0000"
	$"FF00 F5FF F500 F62B F7F8 FFF8 F5F8 F892"
	$"92E3 92E3 9292 92E3 F8F8 FF00 0000 0000"
	$"FF00 00FF 00F6 2BF7 F8F9 FFF8 F8F8 F892"
	$"9292 9292 E392 92E3 F82B FF00 0000 0000"
	$"FF00 F5FD F62B F7F8 F9FA FFF6 F6FF FFFF"
	$"92FF FF92 FFFF FFFF F82B FFFC 0000 0000"
	$"FF00 00F5 FDF7 F8F9 FAFD 00F5 00F5 F8F8"
	$"F892 9292 9292 F8F8 F82B FFFC FCFC 0000"
	$"FF00 F500 F5FD FFFF FF00 F500 F5F8 F8F6"
	$"F6F8 F892 9292 F8F6 F62B FFFC FCFC FCFC"
	$"FF00 00F5 00F5 00F5 00F5 00F5 F8F6 F6F5"
	$"00F5 F8F8 F8F8 F8F6 002B FFFC FCFC FCFC"
	$"FF00 F500 F500 F500 F500 F500 F8F6 F500"
	$"F500 F8F6 F6F6 F6F6 F52B FFFC FCFC 0000"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FFFF FFFC"
};

resource 'icl8' (131) {
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FF00 0000 0000 0000 0000 0000"
	$"FF00 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 FFFF 0000 0000 0000 0000 0000"
	$"FF00 FFFF FFFF FFF5 F5FF F5F5 F5FF FFFF"
	$"F5F5 2BFF FFF8 FF00 0000 0000 0000 0000"
	$"FF00 F5F5 FFF5 F5F5 FBF5 FBF5 F5FF F52B"
	$"FFF5 FFF5 FF00 F8FF 0000 0000 0000 0000"
	$"FF00 F5F5 FFF5 F5F6 FFF5 FFF6 F5FF F5F5"
	$"FFF5 2BFF FF00 00F8 FF00 0000 0000 0000"
	$"FF00 F5F5 FFF5 F5FB FFFF FFFB F5FF F52B"
	$"FFF5 F5F5 FFF5 F6F6 F8FF 0000 0000 0000"
	$"FF00 F5F5 FFF5 F6FF F5F5 F5FF F6FF FFFF"
	$"F5F5 FFFF FFFF FFFF FFFF FF00 0000 0000"
	$"FF00 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F9 F9F9 F9F9 FF00 0000 0000"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FFFF FF00 0000 0000"
	$"FF00 00F5 00F5 00F5 00F5 00F5 00F5 00F5"
	$"00F5 00F5 00F5 00F5 002B FF00 0000 0000"
	$"FF00 F500 F500 F500 F500 F500 F500 F500"
	$"F500 F500 F500 F500 F52B FF00 0000 0000"
	$"FF00 00F5 00F5 00F5 00F5 00F5 00F5 00FA"
	$"00F5 00F5 00F5 00F5 002B FF00 0000 0000"
	$"FF00 F500 F500 F500 F500 F500 F5F9 5600"
	$"FA00 F500 F500 F500 F52B FF00 0000 0000"
	$"FF00 00F5 00F5 00F5 00F5 00F5 00FF 00FA"
	$"FAFA 00F5 00F5 00F5 002B FF00 0000 0000"
	$"FF00 F500 F500 F500 F500 F5F9 5600 FAFA"
	$"FAFA FA00 F500 F500 F52B FF00 0000 0000"
	$"FF00 00F5 00F5 00F5 00F5 00FF 00FA FAFA"
	$"FAFA FAFA 00F5 00F5 002B FF00 0000 0000"
	$"FF00 F500 F500 F500 F5F9 5600 FAFA FAFA"
	$"FAFA F8FF FF00 F500 F52B FF00 0000 0000"
	$"FF00 00F5 00F5 00F5 00FF 00FA FAFA FAFA"
	$"FAF8 FFFF 00F5 00F5 002B FF00 0000 0000"
	$"FF00 F500 F500 F5F9 5600 FAFA FAFA FAFA"
	$"F8FF FFFF F900 F500 F52B FF00 0000 0000"
	$"FF00 00F5 00F5 00FF 00FA FAFA FAFA FAF8"
	$"FFFF 00FB FAF5 00F5 002B FF00 0000 0000"
	$"FF00 F500 F5F9 5600 FAFA FAFA FAFA F8FF"
	$"FFFF F9FB FA00 F500 F52B FF00 0000 0000"
	$"FF00 00F5 00FA FFF8 FAFA FAFA FAF8 FFFF"
	$"00FB FAF5 FAF5 00F5 002B FF00 0000 0000"
	$"FF00 F500 F5FA FFFA F8FA FAFA F8FF FFFF"
	$"F9FB FA00 F500 F500 F52B FF00 0000 0000"
	$"FF00 00F5 00FA FFFA FAF8 FAF8 FFFF 00FB"
	$"FAF5 FAF5 00F5 00F5 002B FF00 0000 0000"
	$"FF00 F500 F5FA F5FF FAFA F8FF FFFF F9FB"
	$"FA00 F500 F500 F500 F52B FF00 0000 0000"
	$"FF00 00F5 00FA 00F5 FFFA FAFF 00FB FAF5"
	$"FAF5 00F5 00F5 00F5 002B FF00 0000 0000"
	$"FF00 F500 F500 F500 F5FF FAFF F9FB FA00"
	$"F500 F500 F500 F500 F52B FFFC 0000 0000"
	$"FF00 00F5 00F5 00F5 00F5 FFF5 FAF5 FAF5"
	$"00F5 00F5 00F5 00F5 002B FFFC FCFC 0000"
	$"FF00 F500 F500 F500 F500 F500 FA00 F500"
	$"F500 F500 F500 F500 F52B FFFC FCFC FCFC"
	$"FF00 00F5 00F5 00F5 00F5 00F5 FAF5 00F5"
	$"00F5 00F5 00F5 00F5 002B FFFC FCFC FCFC"
	$"FF00 F500 F500 F500 F500 F500 F500 F500"
	$"F500 F500 F500 F500 F52B FFFC FCFC 0000"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FFFF FFFC"
};


// ---------------------------------------------------------------------------------------
// -- Small icons.

// ...............................................
// .. ics#

resource 'ics#' (128) {
	{	/* array: 2 elements */
		/* [1] */
		$"0000 FFFC 8007 8005 FFDD 802A 8656 88AB"
		$"BDD1 DEE1 8A9D 9D47 A6E4 8794 8904 FFFC",
		/* [2] */
		$"0000 FFFC FFFF FFFF FFFF FFFE FFFE FFFF"
		$"FFFF FFFF FFFF FFFF FFFC FFFC FFFC FFFC"
	}
};

resource 'ics#' (130) {
	{	/* array: 2 elements */
		/* [1] */
		$"FF80 80C0 80A0 FF90 80F8 9808 BC08 BDC8"
		$"9808 8008 9808 A408 A5C8 980E 800F FFFE",
		/* [2] */
		$"FF80 FFC0 FFE0 FFF0 FFF8 FFF8 FFF8 FFF8"
		$"FFF8 FFF8 FFF8 FFF8 FFF8 FFFE FFFF FFFE"
	}
};

resource 'ics#' (131) {
	{	/* array: 2 elements */
		/* [1] */
		$"FF80 80C0 80A0 FF90 80F8 8108 8288 85C8"
		$"8B48 96C8 BD48 AB08 B508 AC0E 840F FFFE",
		/* [2] */
		$"FF80 FFC0 FFE0 FFF0 FFF8 FFF8 FFF8 FFF8"
		$"FFF8 FFF8 FFF8 FFF8 FFF8 FFFE FFFF FFFE"
	}
};

// ...............................................
// .. ics4

resource 'ics4' (128) {
	$"0000 0000 0000 0000 FFFF FFFF FFFF FF00"
	$"F000 0000 0000 0DFF F000 0000 0000 0F4F"
	$"FFFF FFFF FF0F FF1F F000 0000 00FD F1F0"
	$"F000 0FF0 0FDF 1FF0 F000 F000 FDF1 FDFF"
	$"F0FF F30F FF1F DCCF FF03 FFF0 FFFD CCCF"
	$"F000 FD8F FF0F FFDF F00F F8D8 8F00 0DFF"
	$"F0F0 0F8D 8FF0 0F00 F000 0FF8 F00F 0F00"
	$"F000 F00F 0000 0F00 FFFF FFFF FFFF FF"
};

resource 'ics4' (130) {
	$"FFFF FFFF F000 0000 F000 0000 FF00 0000"
	$"F000 0000 F0F0 0000 FFFF FFFF F00F 0000"
	$"F000 0000 FFFF F000 F00F F000 CCCC F000"
	$"F0FF AF0C 000C F000 F0FA EF0F FF0C F000"
	$"F00F FCCC 000C F000 F00C 0CC8 0CCC F000"
	$"F00F FC8C 8C0C F000 F0FC CFC8 C8CC F000"
	$"F0FC DFCF FFCC F000 F00F F0C0 CC0C FEE0"
	$"F000 0C00 C00C FEEE FFFF FFFF FFFF FEE0"
};

resource 'ics4' (131) {
	$"FFFF FFFF F000 0000 F000 0000 FF00 0000"
	$"F000 0000 F0F0 0000 FFFF FFFF F00F 0000"
	$"F000 0000 FFFF F000 F000 000F 0CCC F000"
	$"F000 00FC F00C F000 F000 0ACD DA0C F000"
	$"F000 ACDD CE0C F000 F00A CDDC AE0C F000"
	$"F0AE DDCA 0E0C F000 F0ED ACAE 000C F000"
	$"F0E0 DA0E 000C F000 F000 0E00 000C FEE0"
	$"F000 0E00 000C FEEE FFFF FFFF FFFF FEE0"
};

// ...............................................
// .. ics8

resource 'ics8' (128) {
	$"0000 0000 0000 0000 0000 0000 0000 0000"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF 0000"
	$"FF00 F5F5 F5F5 F5F5 F5F5 F5F5 F5FA FFFF"
	$"FF00 F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 13FF"
	$"FFFF FFFF FFFF FFFF FFFF F5FF FFFF 05FF"
	$"FF00 00F5 00F5 00F5 00F5 FF33 FF05 FF00"
	$"FF00 F500 F5FF FF00 F5FF 33FF 05FF FF00"
	$"FF00 00F5 FFF5 00F5 FF33 FF05 FF33 FFFF"
	$"FF00 FFFF FFD8 F5FF FFFF 05FF 3308 08FF"
	$"FFFF 00D8 FFFF FF00 FFFF FF33 0808 08FF"
	$"FF00 F500 FF9F E3FF FFFF F5FF FFFF 33FF"
	$"FF00 00FF FFE3 9FE3 E3FF 00F5 00FA FFFF"
	$"FF00 FF00 F5FF E39F E3FF FF00 F5FF 0000"
	$"FF00 00F5 00FF FFE3 FFF5 00FF 00FF 0000"
	$"FF00 F500 FF00 00FF F500 F500 F5FF 0000"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
};

resource 'ics8' (130) {
	$"FFFF FFFF FFFF FFFF FF00 0000 0000 0000"
	$"FFF5 F5F5 F5F5 F5F5 FFFF 0000 0000 0000"
	$"FFF5 F5F5 F5F5 F5F5 FFF5 FF00 0000 0000"
	$"FFFF FFFF FFFF FFFF FF00 F5FF 0000 0000"
	$"FFF5 00F5 00F5 00F5 FFFF FFFF FF00 0000"
	$"FF00 F5FF FF00 F500 F8F8 F8F8 FF00 0000"
	$"FFF5 FFFE FDFF 00F8 00F5 002B FF00 0000"
	$"FF00 FFFD FCFF F5FF FFFF F52B FF00 0000"
	$"FFF5 F5FF FFF8 13F8 00F5 002B FF00 0000"
	$"FF00 F5F8 F513 E392 F5F8 F82B FF00 0000"
	$"FFF5 F5FF FFF8 92E3 92F8 F52B FF00 0000"
	$"FF00 FFF6 F7FF F892 E392 F82B FF00 0000"
	$"FFF5 FFF7 F9FF F8FF FFFF F82B FF00 0000"
	$"FF00 F5FF FFF5 F800 F8F8 F52B FFFC FC00"
	$"FFF5 00F5 00F8 00F5 F8F5 002B FFFC FCFC"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFC FC"
};

resource 'ics8' (131) {
	$"FFFF FFFF FFFF FFFF FF00 0000 0000 0000"
	$"FF00 F5F5 F5F5 F5F5 FFFF 0000 0000 0000"
	$"FF00 F5F5 F5F5 F5F5 FFF5 FF00 0000 0000"
	$"FFFF FFFF FFFF FFFF FF00 F5FF 0000 0000"
	$"FF00 F500 F500 F500 FFFF FFFF FF00 0000"
	$"FF00 00F5 00F5 00FE F5F8 F8F8 FF00 0000"
	$"FF00 F500 F500 FEF6 FE00 F52B FF00 0000"
	$"FF00 00F5 00FD F6F9 F9FD 002B FF00 0000"
	$"FF00 F500 FDF6 F9F9 F8FC F52B FF00 0000"
	$"FF00 00FD F6F9 F9F8 FDFB 002B FF00 0000"
	$"FF00 FDFC F9F9 F8FD F5FB F52B FF00 0000"
	$"FF00 FBF9 FDF8 FDFB 00F5 002B FF00 0000"
	$"FF00 FB00 F9FD F5FB F500 F52B FF00 0000"
	$"FF00 00F5 00FB 00F5 00F5 002B FFFC FC00"
	$"FF00 F500 F5FB F500 F500 F52B FFFC FCFC"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFC FC"
};

